==> fultra-0.3.0.tgz: package/README.md <==
# Fultra

<img align="left" src="https://github.com/JayDemitri/Fultra/blob/master/libs/src/img/FULTRA-prototype-v1.png" height="150px" width="150px">

Fultra is an angular-powered framework for building powerful responsive web based applications. Combining the best of foundation for apps and sites the aim of fultra is to provide a set of tools that can be used to build modern, fast and responsive web applications.

Fultra is planned to have alot of features that foundation did not already have like built in compatibility with node-webkit and angular powered alternative to orbit and more.

---------------------------------------------------------

## Release Infomation

**Release**: n/a

**Documentation Status**: FIRST DRAFT - Everything is subkect to change

**Build Infomation & Status**:

[![GitHub version](https://badge.fury.io/gh/JayDemitri%2FFultra.png)](https://badge.fury.io/gh/JayDemitri%2FFultra)
[![npm version](https://badge.fury.io/js/fultra.png)](https://badge.fury.io/js/fultra)
[![Dependency Status](https://gemnasium.com/badges/github.com/JayDemitri/Fultra.svg)](https://gemnasium.com/github.com/JayDemitri/Fultra)
[![Build Status](https://travis-ci.org/JayDemitri/Fultra.svg?branch=master)](https://travis-ci.org/JayDemitri/Fultra)
[ ![Codeship Status for JayDemitri/Fultra](https://codeship.com/projects/7f241930-67f0-0134-dd3d-5ade36a91ecb/status?branch=master)](https://codeship.com/projects/176325)
[![GitHub forks](https://img.shields.io/github/forks/JayDemitri/Fultra.svg?style=plastic)](https://github.com/JayDemitri/Fultra/network)
[![GitHub stars](https://img.shields.io/github/stars/JayDemitri/Fultra.svg?style=plastic)](https://github.com/JayDemitri/Fultra/stargazers)
[![GitHub issues](https://img.shields.io/github/issues/JayDemitri/Fultra.svg?style=plastic)](https://github.com/JayDemitri/Fultra/issues)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg?style=plastic)](https://raw.githubusercontent.com/JayDemitri/Fultra/master/LICENSE.md)

-----------------------------------------------------------

## Contents
 - [Demo](#demo)
 - [Features](#features)
 - [Requirements](#requirements)
 - [Getting Started](#getting-started)
 - [Docs](#docs)
 - [Directory Structure](#directory-structure)
 - [Support / Contributing](#contribute)
 - [Versioning](#versioning)
 - [Release History](#history)
 - [License](#license)

## Demo <a name="demo"></a>

Will Update Later

## Features <a name="features"></a>

The Main List

- Foundation-Apps
- Font-Awesome

Will Update Later

## Requirements <a name="requirements"></a>

- **NodeJs** | Install using thier installer provided on the NodeJs website
- **Git** | Use the installer provided for your OS, Windows users have a look at RailsInstaller or Github for Windows
- **Ruby** | Use the installer provided for your OS, Windows users once again have a look at RailsInstaller or JRuby
	- With Ruby installed open a command prompt and use the following command `gem install sass`
- **Gulp** and Bower | Open a command prompt with NodeJs & Npm Installed 
	- Type `[sudo] npm install -g gulp bower`

## Getting Started <a name="getting-started"></a>

#### Installation

The Sass and Js components are available directly on bower, composer and npm using one of the following:

```bash

// As an npm package
npm install --save fultra

// As a bower component
bower install --save fultra

// Or with composer
composer require fultra

```

You can then just link to the compiled libs in `./libs/release/` or use our source code directly from the `./libs/src` folder

[We will soon have a command line interface for directly creating fultra apps this will be built into this project untill ready]

#### Building This Repo & The Docs

If you want to work with the the source code directly or compile the documentation for local use follow these steps

```
git clone https://github.com/JayDemitri/Fultra.git
cd fultra
npm install
bower install
// Then for a list of commands type 'gulp' or 
gulp launch:docs
```

## Documentation <a name="docs"></a>

For the momment any documentation we have will be contained as an application within the repo that can be compiled using the above.

Alternativly any documentation will be kept on our wiki page and added on an ad-hoc basis.

Will Update Later

## Directory Structure <a name="directory-structure"></a>

Currently We are using the following structure:

- /ROOT/
	- docs/
	- libs/
	- tests/

We are thinking about changing it to the following

-/ROOT/
	-

## Support / Contributing <a name="contribute"></a>

We are still working this part out as we are working trello into our development workflow.

Will Update Later.

## Versioning <a name="versioning"></a>

Just like Foundation, Fultra follows semver and will apply from v1.0.0.
so braking changes will not be introduced in minor or patch versions.

Unlike foundation we work our repo branches a little differently.

 Our `master` branch will always contain stable production ready code. 

 Our `beta` branch is were our latest features are released for users to play with and thus although should be stable is not production ready.

 Our 'devevelopment' branch speak for itself.

## Release History <a name="history"></a>

We are currently working to v1.0.0 on the master branch of this repo release history upto this point is tracked through our trello boards and commits, sorry.

## License <a name="license"></a>

Fultra is release under the MIT License a compy of which is included in the root of the project. Please Note that since fultra is backboned from Zurbs Foundation Sites/Apps All License's Belonging to them remain inplace.

#### The MIT License (MIT)

**Copyright (c) 2016 Jay Demitri | London Development Studio**

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

*THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR*
*IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,*
*FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE*
*AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER*
*LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,*
*OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE*
*SOFTWARE.*

==> fultra-0.5.0.tgz: package/README.md <==
# Fultra

<img align="left" src="https://github.com/JayDemitri/Fultra/blob/master/img/FULTRA-prototype-v1.png" height="150px" width="150px">

Fultra is an angular-powered framework for building powerful responsive web based applications. Combining the best of foundation for apps and sites the aim of fultra is to provide a set of tools that can be used to build modern, fast and responsive web applications.

Fultra is planned to have alot of features that foundation did not already have like built in compatibility with node-webkit and angular powered alternative to orbit and more.

---------------------------------------------------------

## Release Infomation

**Release**: n/a

**Documentation Status**: FIRST DRAFT - Everything is subkect to change

**Build Infomation & Status**:

[![GitHub version](https://badge.fury.io/gh/JayDemitri%2FFultra.png)](https://badge.fury.io/gh/JayDemitri%2FFultra)
[![npm version](https://badge.fury.io/js/fultra.png)](https://badge.fury.io/js/fultra)
[![Dependency Status](https://gemnasium.com/badges/github.com/JayDemitri/Fultra.svg)](https://gemnasium.com/github.com/JayDemitri/Fultra)
[![Build Status](https://travis-ci.org/JayDemitri/Fultra.svg?branch=master)](https://travis-ci.org/JayDemitri/Fultra)
[ ![Codeship Status for JayDemitri/Fultra](https://codeship.com/projects/7f241930-67f0-0134-dd3d-5ade36a91ecb/status?branch=master)](https://codeship.com/projects/176325)
[![GitHub forks](https://img.shields.io/github/forks/JayDemitri/Fultra.svg?style=plastic)](https://github.com/JayDemitri/Fultra/network)
[![GitHub stars](https://img.shields.io/github/stars/JayDemitri/Fultra.svg?style=plastic)](https://github.com/JayDemitri/Fultra/stargazers)
[![GitHub issues](https://img.shields.io/github/issues/JayDemitri/Fultra.svg?style=plastic)](https://github.com/JayDemitri/Fultra/issues)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg?style=plastic)](https://raw.githubusercontent.com/JayDemitri/Fultra/master/LICENSE.md)

-----------------------------------------------------------

## Contents
 - [Demo](#demo)
 - [Features](#features)
 - [Requirements](#requirements)
 - [Getting Started](#getting-started)
 - [Docs](#docs)
 - [Directory Structure](#directory-structure)
 - [Support / Contributing](#contribute)
 - [Versioning](#versioning)
 - [Release History](#history)
 - [License](#license)

## Demo <a name="demo"></a>

Will Update Later

## Features <a name="features"></a>

The Main List

- Foundation-Apps
- Font-Awesome

Will Update Later

## Requirements <a name="requirements"></a>

- **NodeJs** | Install using thier installer provided on the NodeJs website
- **Git** | Use the installer provided for your OS, Windows users have a look at RailsInstaller or Github for Windows
- **Ruby** | Use the installer provided for your OS, Windows users once again have a look at RailsInstaller or JRuby
	- With Ruby installed open a command prompt and use the following command `gem install sass`
- **Gulp** and Bower | Open a command prompt with NodeJs & Npm Installed 
	- Type `[sudo] npm install -g gulp bower`

## Getting Started <a name="getting-started"></a>

#### Installation

The Sass and Js components are available directly on bower, composer and npm using one of the following:

```bash

// As an npm package
npm install --save fultra

// As a bower component
bower install --save fultra

// Or with composer
composer require fultra

```

You can then just link to the compiled libs in `./libs/release/` or use our source code directly from the `./libs/src` folder

[We will soon have a command line interface for directly creating fultra apps this will be built into this project untill ready]

#### Building This Repo & The Docs

If you want to work with the the source code directly or compile the documentation for local use follow these steps

```
git clone https://github.com/JayDemitri/Fultra.git
cd fultra
npm install
bower install
// Then for a list of commands type 'gulp' or 
gulp launch:docs
```

## Documentation <a name="docs"></a>

For the moment any documentation we have will be contained as an application within the repo that can be compiled using the above.

Alternatively any documentation will be kept on our wiki page and added on an ad-hoc basis.

Will Update Later

## Directory Structure <a name="directory-structure"></a>

Currently We are using the following structure:

- /ROOT/
	- bin/              | Our NodeJs files are kept in ere
	- build/            | Our Application in most cases the docs are built here
	- dist/             | Fultras Distibutable files are here
	- docs/             | Fultras Documentation App (Raw)
	- fonts/            | Any Font Here
	- gulp/             | Our Gulp Tasks are here to allow better modularization 
	- img/              | Images
	- js/               | Any Javascript from angular to jquery plugins go here
	- node_modules/     | Node modules are kept here when you install
	- scss/             | Scss Libs
	- vendor/           | Bower Dependencies
	- tests/            | Any Tests


## Support / Contributing <a name="contribute"></a>

We are still working this part out as we are working trello into our development workflow.

Will Update Later.

## Versioning <a name="versioning"></a>

Just like Foundation, Fultra follows semver and will apply from v1.0.0.
so braking changes will not be introduced in minor or patch versions.

Unlike foundation we work our repo branches a little differently.

 Our `master` branch will always contain stable production ready code. 

 Our `beta` branch is were our latest features are released for users to play with and thus although should be stable is not production ready.

 Our `development` branch speak for itself.

## Release History <a name="history"></a>

We are currently working to v1.0.0 on the master branch of this repo release history upto this point is tracked through our trello boards and commits, sorry.

## License <a name="license"></a>

Fultra is release under the MIT License a compy of which is included in the root of the project. Please Note that since fultra is backboned from Zurbs Foundation Sites/Apps All License's Belonging to them remain inplace.

### The MIT License (MIT)

**Copyright (c) 2016 Jay Demitri | London Development Studio**

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

*THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR*
*IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,*
*FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE*
*AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER*
*LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,*
*OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE*
*SOFTWARE.*
